@@ -5,7 +5,7 @@ import (
 	"reflect"
 	"testing"
 
-	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/enumeration/resource"
 )
 
 func TestFilterEngine_Run(t *testing.T) {
