@@ -5,8 +5,8 @@ import (
 	"strings"
 
 	"github.com/sirupsen/logrus"
-	"github.com/snyk/driftctl/pkg/resource"
-	"github.com/snyk/driftctl/pkg/resource/google"
+	"github.com/snyk/driftctl/enumeration/resource"
+	"github.com/snyk/driftctl/enumeration/resource/google"
 )
 
 // Some service accounts are created by default when activating APIs, this middleware will filter them unless they are managed.
