@@ -22,17 +22,7 @@ func TestAcc_Aws_Eip(t *testing.T) {
 				Env: map[string]string{
 					"AWS_REGION": "us-east-1",
 				},
-				// New resources are not visible immediately through AWS API after an apply operation
-				// (e.g. error attaching EC2 Internet Gateway)
-				// Logic below retries driftctl scan using a back-off strategy of retrying 'n' times
-				// and doubling the amount of time waited after each one.
-				ShouldRetry: func(result *test.ScanResult, retryDuration time.Duration, retryCount uint8) bool {
-					if result.IsSync() || retryDuration > 10*time.Minute {
-						return false
-					}
-					time.Sleep((2 * time.Duration(retryCount)) * time.Minute)
-					return true
-				},
+				ShouldRetry: acceptance.LinearBackoff(20 * time.Minute),
 				Check: func(result *test.ScanResult, stdout string, err error) {
 					if err != nil {
 						t.Fatal(err)
