@@ -12,7 +12,7 @@ import (
 	"github.com/snyk/driftctl/test/acceptance"
 )
 
-func TestAcc_AwsSQSQueuePolicy(t *testing.T) {
+func TestAcc_Aws_SQSQueuePolicy(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_sqs_queue_policy"},
